@@ -1,4 +1,4 @@
-# Copyright 2012-2018 CERN for the benefit of the ATLAS collaboration.
+# Copyright 2012-2020 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,13 +13,15 @@
 # limitations under the License.
 #
 # Authors:
-# - Mario Lassnig <mario@lassnig.net>, 2012-2013
-# - Vincent Garonne <vgaronne@gmail.com>, 2012-2018
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2012-2013
+# - Vincent Garonne <vincent.garonne@cern.ch>, 2012-2018
 # - Martin Barisits <martin.barisits@cern.ch>, 2012
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 
 import gettext
+import sys
 
-try:
-    gettext.install('rucio', unicode=1)
-except TypeError:
-    gettext.install(u'rucio')
+if sys.version_info < (3,):
+    gettext.install('rucio', unicode=1)  # pylint: disable=unexpected-keyword-arg
+else:
+    gettext.install('rucio')
