@@ -1,4 +1,4 @@
-# Copyright 2014-2018 CERN for the benefit of the ATLAS collaboration.
+# Copyright 2014-2020 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,23 +14,27 @@
 #
 # Authors:
 # - David Cameron <david.cameron@cern.ch>, 2014
+# - Vincent Garonne <vincent.garonne@cern.ch>, 2016
 # - Cedric Serfon <cedric.serfon@cern.ch>, 2017
 # - Joaquin Bogado <jbogado@linti.unlp.edu.ar>, 2018
-# - Nicolo Magini, <nicolo.magini@cern.ch>, 2018
+# - Nicolo Magini <nicolo.magini@cern.ch>, 2018
+# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2018
+# - Tomas Javurek <tomas.javurek@cern.ch>, 2020
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 #
 # PY3K COMPATIBLE
 
 import errno
 import os
 
+from rucio.common.exception import FileAlreadyExists, ServiceUnavailable, SourceNotFound
+from rucio.rse.protocols import protocol
+
 try:
     import arc  # pylint: disable=import-error
 except:
     pass
 
-from rucio.rse.protocols import protocol
-from rucio.common.exception import FileAlreadyExists, ServiceUnavailable, SourceNotFound
-
 
 class DataPoint:
     '''
@@ -50,11 +54,11 @@ class DataPoint:
 class Default(protocol.RSEProtocol):
     """ Implementing access to RSEs using ARC client."""
 
-    def __init__(self, protocol_attr, rse_settings):
+    def __init__(self, protocol_attr, rse_settings, logger=None):
         """
         Set up UserConfig object.
         """
-        super(Default, self).__init__(protocol_attr, rse_settings)
+        super(Default, self).__init__(protocol_attr, rse_settings, logger=logger)
 
         # Arc logging to stdout, uncomment for debugging. Should use root
         # logger level eventually.
@@ -66,7 +70,7 @@ class Default(protocol.RSEProtocol):
 
         self.cfg = arc.UserConfig()
         try:
-            self.cfg.ProxyPath(str(os.getenv(['X509_USER_PROXY'])))
+            self.cfg.ProxyPath(os.environ['X509_USER_PROXY'])
         except:
             pass
 
