@@ -1,16 +1,29 @@
-# Copyright European Organization for Nuclear Research (CERN)
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-# http://www.apache.org/licenses/LICENSE-2.0
-#
-# Authors:
-# - Ralph Vigne, <ralph.vigne@cern.ch>, 2012-2014
+'''
+ Copyright European Organization for Nuclear Research (CERN)
 
+ Licensed under the Apache License, Version 2.0 (the "License");
+ You may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+ http://www.apache.org/licenses/LICENSE-2.0
 
+ Authors:
+ - Ralph Vigne, <ralph.vigne@cern.ch>, 2012-2014
+ - Mario Lassnig, <mario.lassnig@cern.ch>, 2017
+ - Nicolo Magini, <nicolo.magini@cern.ch>, 2018
+ - Hannes Hansen, <hannes.jakob.hansen@cern.ch>, 2019
+ - Eli Chadwick, <eli.chadwick@stfc.ac.uk>, 2020
+
+ PY3K COMPATIBLE
+'''
+
+from six import string_types
 from subprocess import call
-from urlparse import urlparse
+try:
+    # PY2
+    from urlparse import urlparse
+except ImportError:
+    # PY3
+    from urllib.parse import urlparse
 # IMPORTANT: If the order of the S3 imports is changed, they fail!
 from S3.Exceptions import S3Error, InvalidFileError
 from S3.S3 import S3
@@ -24,8 +37,8 @@ from rucio.rse.protocols import protocol
 class Default(protocol.RSEProtocol):
     """ Implementing access to RSEs using the S3 protocol."""
 
-    def __init__(self, protocol_attr, rse_settings):
-        super(Default, self).__init__(protocol_attr, rse_settings)
+    def __init__(self, protocol_attr, rse_settings, logger=None):
+        super(Default, self).__init__(protocol_attr, rse_settings, logger=logger)
         if 'determinism_type' in self.attributes:
             self.attributes['determinism_type'] = 's3'
 
@@ -74,7 +87,7 @@ class Default(protocol.RSEProtocol):
             self.__s3.object_info(S3Uri(pfn))
             return True
         except S3Error as e:
-            if e.status == 404:
+            if e.status in [404, 204]:
                 return False
             else:
                 raise exception.ServiceUnavailable(e)
@@ -99,12 +112,13 @@ class Default(protocol.RSEProtocol):
         """ Closes the connection to RSE."""
         pass
 
-    def get(self, pfn, dest):
+    def get(self, pfn, dest, transfer_timeout=None):
         """
             Provides access to files stored inside connected the RSE.
 
             :param path: Physical file name of requested file
             :param dest: Name and path of the files when stored at the client
+            :param transfer_timeout: Transfer timeout (in seconds) - dummy
 
             :raises DestinationNotAccessible: if the destination storage was not accessible.
             :raises ServiceUnavailable: if some generic error occured in the library.
@@ -113,12 +127,12 @@ class Default(protocol.RSEProtocol):
         tf = None
         try:
             tf = open(dest, 'wb')
-            self.__s3.object_get(S3Uri(pfn), tf)
+            self.__s3.object_get(S3Uri(pfn), tf)  # pylint: disable=no-value-for-parameter
             tf.close()
         except S3Error as e:
             tf.close()
             call(['rm', dest])  # Must be changed if resume will be supported
-            if e.status in [404, 403]:
+            if e.status in [404, 403, 204]:
                 raise exception.SourceNotFound(e)
             else:
                 raise exception.ServiceUnavailable(e)
@@ -128,13 +142,14 @@ class Default(protocol.RSEProtocol):
             else:
                 raise exception.ServiceUnavailable(e)
 
-    def put(self, source, target, source_dir=None):
+    def put(self, source, target, source_dir=None, transfer_timeout=None):
         """
             Allows to store files inside the referred RSE.
 
             :param source: path to the source file on the client file system
             :param target: path to the destination file on the storage
             :param source_dir: Path where the to be transferred files are stored in the local file system
+            :param transfer_timeout: Transfer timeout (in seconds) - dummy
 
             :raises DestinationNotAccessible: if the destination storage was not accessible.
             :raises ServiceUnavailable: if some generic error occured in the library.
@@ -148,8 +163,8 @@ class Default(protocol.RSEProtocol):
                 raise exception.DestinationNotAccessible(e)
             else:
                 raise exception.ServiceUnavailable(e)
-        except InvalidFileError as e:
-                raise exception.SourceNotFound(e)
+        except InvalidFileError as error:
+            raise exception.SourceNotFound(error)
 
     def delete(self, pfn):
         """
@@ -163,7 +178,7 @@ class Default(protocol.RSEProtocol):
         try:
             self.__s3.object_delete(S3Uri(pfn))
         except S3Error as e:
-            if e.status in [404, 403]:
+            if e.status in [404, 403, 204]:
                 raise exception.SourceNotFound(e)
             else:
                 raise exception.ServiceUnavailable(e)
@@ -181,7 +196,7 @@ class Default(protocol.RSEProtocol):
         try:
             self.__s3.object_move(S3Uri(pfn), S3Uri(new_pfn))
         except S3Error as e:
-            if e.status in [404, 403]:
+            if e.status in [404, 403, 204]:
                 if self.exists(pfn):
                     raise exception.SourceNotFound(e)
                 else:
@@ -202,7 +217,7 @@ class Default(protocol.RSEProtocol):
         """
         # s3 URI: s3://[Bucket]/[path]/[name]; Bucket/path = scope/user
         ret = dict()
-        pfns = [pfns] if ((type(pfns) == str) or (type(pfns) == unicode)) else pfns
+        pfns = [pfns] if isinstance(pfns, string_types) else pfns
 
         for pfn in pfns:
             parsed = urlparse(pfn)
@@ -216,12 +231,14 @@ class Default(protocol.RSEProtocol):
             path = path.partition(self.attributes['prefix'])[2]
             name = path.split('/')[-1]
             path = path.partition(name)[0]
+            if not path.startswith('/'):
+                path = '/' + path
             ret[pfn] = {'path': path, 'name': name, 'scheme': scheme, 'prefix': prefix, 'port': port, 'hostname': hostname, }
 
         return ret
 
     def pfn2path(self, pfn):
-        tmp = self.parse_pfn(pfn)
+        tmp = self.parse_pfns(pfn)
         return '/'.join([tmp['path'], tmp['name']])
 
     def stat(self, pfn):
