@@ -1,17 +1,29 @@
-# Copyright European Organization for Nuclear Research (CERN)
+# -*- coding: utf-8 -*-
+# Copyright 2014-2020 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
-# You may obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
 # Authors:
-# - Mario Lassnig, <mario.lassnig@cern.ch>, 2014
-# - Hannes Hansen, <hannes.jakob.hansen@cern.ch>, 2019
+# - Mario Lassnig <mario.lassnig@cern.ch>, 2014
+# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 
-from nose.tools import assert_equal, assert_in, assert_is_instance, assert_true, assert_raises
+import unittest
+
+import pytest
 
-from rucio.client.configclient import ConfigClient
 import rucio.core.config as config_core
+from rucio.client.configclient import ConfigClient
 from rucio.common import exception
 from rucio.common.utils import generate_uuid
 
@@ -25,7 +37,7 @@ class TestConfigCore:
             config_core.set(section, str(generate_uuid()), str(generate_uuid()))
         sections = config_core.sections(use_cache=False)
         for section in expected_sections:
-            assert_in(section, sections)
+            assert section in sections
 
     def test_get_and_set_section_option(self):
         """ CONFIG (CORE): Retreive configuration option only """
@@ -35,14 +47,14 @@ class TestConfigCore:
         expected_value = str(generate_uuid())
         config_core.set(section=section, option=option, value=expected_value)
         value = config_core.get(section, option, use_cache=False)
-        assert_equal(value, expected_value)
+        assert value == expected_value
 
         # default value
         section = str(generate_uuid())
         config_core.set(section=section, option=str(generate_uuid()), value=str(generate_uuid()))
         default_value = 'default'
         value = config_core.get(section, 'new_option', default=default_value, use_cache=False)
-        assert_equal(value, default_value)
+        assert value == default_value
 
         # key with space character
         section = str(generate_uuid() + ' ')
@@ -50,13 +62,26 @@ class TestConfigCore:
         expected_value = str(generate_uuid())
         config_core.set(section=section, option=option, value=expected_value)
         value = config_core.get(section, option, use_cache=False)
-        assert_equal(value, expected_value)
+        assert value == expected_value
 
 
-class TestConfigClients:
+@pytest.mark.xfail(reason='ConfigClient bug https://github.com/rucio/rucio/issues/3916')
+def test_config_section_contextless():
+    config = ConfigClient()
+    test_section_1 = generate_uuid()
+    test_section_2 = generate_uuid()
+    config.set_config_option(test_section_1, 'a', 'b')
+    config.set_config_option(test_section_2, 'c', 'd')
 
-    @classmethod
-    def setupClass(self):
+    value = config.get_config(None, None)
+
+    assert isinstance(value, dict)
+    assert list(value.keys()) == [test_section_1, test_section_2]
+
+
+class TestConfigClients(unittest.TestCase):
+
+    def setUp(self):
         self.c = ConfigClient()
         self.test_section_1 = str(generate_uuid())
         self.test_section_2 = str(generate_uuid())
@@ -73,38 +98,35 @@ class TestConfigClients:
         self.c.set_config_option(self.test_section_2, self.test_option_i, self.test_option_iv)
         self.c.set_config_option(self.test_section_2, self.test_option_f, self.test_option_fv)
 
-    @classmethod
-    def tearDownClass(self):
-        self.c.delete_config_option(self.test_section_1, self.test_option_s)
-        self.c.delete_config_option(self.test_section_1, self.test_option_b)
-        self.c.delete_config_option(self.test_section_2, self.test_option_i)
-        self.c.delete_config_option(self.test_section_2, self.test_option_f)
+    def tearDown(self):
+        self.c = None
 
+    @pytest.mark.xfail(reason='ConfigClient bug https://github.com/rucio/rucio/issues/3916')
     def test_get_config_all(self):
         """ CONFIG (CLIENT): Retrieve configuration values and check for correctness """
         tmp = self.c.get_config(None, None)
-        assert_is_instance(tmp, dict)
-        assert_in(self.test_section_1, tmp.keys())
-        assert_in(self.test_option_s, tmp[self.test_section_1])
-        assert_in(self.test_option_b, tmp[self.test_section_1])
-        assert_equal(self.test_option_sv, tmp[self.test_section_1][self.test_option_s])
-        assert_true(tmp[self.test_section_1][self.test_option_b])
-        assert_in(self.test_option_i, tmp[self.test_section_2])
-        assert_in(self.test_option_f, tmp[self.test_section_2])
-        assert_equal(543210, tmp[self.test_section_2][self.test_option_i])
-        assert_equal(3.1415, tmp[self.test_section_2][self.test_option_f])
+        assert isinstance(tmp, dict)
+        assert self.test_section_1 in tmp.keys()
+        assert self.test_option_s in tmp[self.test_section_1]
+        assert self.test_option_b in tmp[self.test_section_1]
+        assert self.test_option_sv == tmp[self.test_section_1][self.test_option_s]
+        assert tmp[self.test_section_1][self.test_option_b]
+        assert self.test_option_i in tmp[self.test_section_2]
+        assert self.test_option_f in tmp[self.test_section_2]
+        assert 543210 == tmp[self.test_section_2][self.test_option_i]
+        assert 3.1415 == tmp[self.test_section_2][self.test_option_f]
 
     def test_get_config_section(self):
         """ CONFIG (CLIENT): Retrieve configuration section only """
         tmp = self.c.get_config(self.test_section_1, None)
-        assert_is_instance(tmp, dict)
-        assert_in(self.test_option_s, tmp.keys())
-        assert_in(self.test_option_b, tmp.keys())
+        assert isinstance(tmp, dict)
+        assert self.test_option_s in tmp.keys()
+        assert self.test_option_b in tmp.keys()
 
     def test_get_config_section_option(self):
         """ CONFIG (CLIENT): Retrieve configuration option only """
         tmp = self.c.get_config(self.test_section_1, self.test_option_s)
-        assert_equal(tmp, self.test_option_sv)
+        assert tmp == self.test_option_sv
 
-        with assert_raises(exception.ConfigNotFound):
+        with pytest.raises(exception.ConfigNotFound):
             self.c.get_config(self.test_section_1, 'no_option')
