@@ -1,28 +1,33 @@
-"""
- Copyright European Organization for Nuclear Research (CERN)
-
- Licensed under the Apache License, Version 2.0 (the "License");
- You may not use this file except in compliance with the License.
- You may obtain a copy of the License at
- http://www.apache.org/licenses/LICENSE-2.0
-
- Authors:
- - Cedric Serfon, <cedric.serfon@cern.ch>, 2017
-"""
+# Copyright 2017-2020 CERN for the benefit of the ATLAS collaboration.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# Authors:
+# - Cedric Serfon <cedric.serfon@cern.ch>, 2017
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 
+import unittest
 from datetime import datetime
 
-from nose.tools import assert_in
-
 from rucio.client.didclient import DIDClient
 from rucio.client.lifetimeclient import LifetimeClient
 from rucio.common.utils import generate_uuid
 from rucio.db.sqla.constants import DIDType
 
 
-class TestDIDClients:
+class TestDIDClients(unittest.TestCase):
 
-    def __init__(self):
+    def setUp(self):
         self.did_client = DIDClient()
         self.lifetime_client = LifetimeClient()
 
@@ -35,4 +40,4 @@ class TestDIDClients:
         exceptions = self.lifetime_client.list_exceptions()
         exception_id = self.lifetime_client.add_exception(dids, account='root', pattern='wekhewfk', comments='This is a comment', expires_at=datetime.now())
         exceptions = [exception['id'] for exception in self.lifetime_client.list_exceptions()]
-        assert_in(exception_id, exceptions)
+        assert exception_id in exceptions
