@@ -1,14 +1,24 @@
-# Copyright European Organization for Nuclear Research (CERN)
+# -*- coding: utf-8 -*-
+# Copyright 2014-2020 CERN for the benefit of the ATLAS collaboration.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
-# You may not use this file except in compliance with the License.
+# you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
-# http://www.apache.org/licenses/LICENSE-2.0
+#
+#    http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 #
 # Authors:
-# - Wen Guan, <wen.guan@cern.ch>, 2014
-# - Joaquin Bogado, <jbogado@linti.unlp.edu.ar>, 2018
-# - Hannes Hansen, <hannes.jakob.hansen@cern.ch>, 2019
+# - Wen Guan <wen.guan@cern.ch>, 2014
+# - Martin Barisits <martin.barisits@cern.ch>, 2016
+# - Joaquín Bogado <jbogado@linti.unlp.edu.ar>, 2018
+# - Hannes Hansen <hannes.jakob.hansen@cern.ch>, 2019
+# - Benedikt Ziemons <benedikt.ziemons@cern.ch>, 2020
 #
 # PY3K COMPATIBLE
 
@@ -17,22 +27,25 @@ from __future__ import print_function
 import json
 import os
 import tempfile
+import unittest
+from uuid import uuid4 as uuid
+
+import boto
+import boto.s3.connection
+import pytest
+from boto.s3.key import Key
+
+from rucio.common import exception
+from rucio.rse import rsemanager as mgr
+from rucio.tests.common import skip_rse_tests_with_accounts
+from rucio.tests.rsemgr_api_test import MgrTestCases
+
 try:
     # PY2
     import urlparse
 except ImportError:
     # PY3
     import urllib.parse as urlparse
-import boto
-import boto.s3.connection
-from boto.s3.key import Key
-
-from nose.tools import raises
-from uuid import uuid4 as uuid
-
-from rucio.common import exception
-from rucio.rse import rsemanager as mgr
-from rsemgr_api_test import MgrTestCases
 
 
 def get_bucket_key_name(pfn):
@@ -57,12 +70,13 @@ def get_bucket_key(pfn, conn, create=False):
     return key
 
 
-class TestRseS3():
+@skip_rse_tests_with_accounts
+class TestRseS3(unittest.TestCase):
     tmpdir = None
     user = None
 
     @classmethod
-    def setupClass(cls):
+    def setUpClass(cls):
         """S3 (RSE/PROTOCOLS): Creating necessary directories and files """
         # Creating local files
         cls.tmpdir = tempfile.mkdtemp()
@@ -71,7 +85,7 @@ class TestRseS3():
 
         with open("%s/data.raw" % cls.tmpdir, "wb") as out:
             out.seek((1024 * 1024) - 1)  # 1 MB
-            out.write('\0')
+            out.write(b'\0')
         for f in MgrTestCases.files_local:
             os.symlink('%s/data.raw' % cls.tmpdir, '%s/%s' % (cls.tmpdir, f))
 
@@ -104,7 +118,7 @@ class TestRseS3():
             bucket_name, key_name = get_bucket_key_name(pfn)
             key.copy(bucket_name, key_name)
 
-    def setup(self):
+    def setUp(self):
         """S3 (RSE/PROTOCOLS): Creating Mgr-instance """
         self.tmpdir = TestRseS3.tmpdir
         self.mtc = MgrTestCases(self.tmpdir, 'BNL-BOTO', TestRseS3.user, TestRseS3.static_file)
@@ -157,20 +171,20 @@ class TestRseS3():
         """S3 (RSE/PROTOCOLS): Get a single file from storage providing PFN (Success)"""
         self.mtc.test_get_mgr_ok_single_pfn()
 
-    @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_multi(self):
         """S3 (RSE/PROTOCOLS): Get multiple files from storage providing LFNs and PFNs (SourceNotFound)"""
-        self.mtc.test_get_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_get_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_single_lfn(self):
         """S3 (RSE/PROTOCOLS): Get a single file from storage providing LFN (SourceNotFound)"""
-        self.mtc.test_get_mgr_SourceNotFound_single_lfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_get_mgr_SourceNotFound_single_lfn()
 
-    @raises(exception.SourceNotFound)
     def test_get_mgr_SourceNotFound_single_pfn(self):
         """S3 (RSE/PROTOCOLS): Get a single file from storage providing PFN (SourceNotFound)"""
-        self.mtc.test_get_mgr_SourceNotFound_single_pfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_get_mgr_SourceNotFound_single_pfn()
 
     # Mgr-Tests: PUT
     def test_put_mgr_ok_multi(self):
@@ -181,25 +195,25 @@ class TestRseS3():
         """S3 (RSE/PROTOCOLS): Put a single file to storage (Success)"""
         self.mtc.test_put_mgr_ok_single()
 
-    @raises(exception.SourceNotFound)
     def test_put_mgr_SourceNotFound_multi(self):
         """S3 (RSE/PROTOCOLS): Put multiple files to storage (SourceNotFound)"""
-        self.mtc.test_put_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_put_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_put_mgr_SourceNotFound_single(self):
         """S3 (RSE/PROTOCOLS): Put a single file to storage (SourceNotFound)"""
-        self.mtc.test_put_mgr_SourceNotFound_single()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_put_mgr_SourceNotFound_single()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_put_mgr_FileReplicaAlreadyExists_multi(self):
         """S3 (RSE/PROTOCOLS): Put multiple files to storage (FileReplicaAlreadyExists)"""
-        self.mtc.test_put_mgr_FileReplicaAlreadyExists_multi()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_put_mgr_FileReplicaAlreadyExists_multi()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_put_mgr_FileReplicaAlreadyExists_single(self):
         """S3 (RSE/PROTOCOLS): Put a single file to storage (FileReplicaAlreadyExists)"""
-        self.mtc.test_put_mgr_FileReplicaAlreadyExists_single()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_put_mgr_FileReplicaAlreadyExists_single()
 
     # MGR-Tests: DELETE
     def test_delete_mgr_ok_multi(self):
@@ -210,15 +224,15 @@ class TestRseS3():
         """S3 (RSE/PROTOCOLS): Delete a single file from storage (Success)"""
         self.mtc.test_delete_mgr_ok_single()
 
-    @raises(exception.SourceNotFound)
     def test_delete_mgr_SourceNotFound_multi(self):
         """S3 (RSE/PROTOCOLS): Delete multiple files from storage (SourceNotFound)"""
-        self.mtc.test_delete_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_delete_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_delete_mgr_SourceNotFound_single(self):
         """S3 (RSE/PROTOCOLS): Delete a single file from storage (SourceNotFound)"""
-        self.mtc.test_delete_mgr_SourceNotFound_single()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_delete_mgr_SourceNotFound_single()
 
     # MGR-Tests: EXISTS
     def test_exists_mgr_ok_multi(self):
@@ -258,35 +272,35 @@ class TestRseS3():
         """S3 (RSE/PROTOCOLS): Rename a single file on storage using PFN (Success)"""
         self.mtc.test_rename_mgr_ok_single_pfn()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_rename_mgr_FileReplicaAlreadyExists_multi(self):
         """S3 (RSE/PROTOCOLS): Rename multiple files on storage (FileReplicaAlreadyExists)"""
-        self.mtc.test_rename_mgr_FileReplicaAlreadyExists_multi()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_rename_mgr_FileReplicaAlreadyExists_multi()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_rename_mgr_FileReplicaAlreadyExists_single_lfn(self):
         """S3 (RSE/PROTOCOLS): Rename a single file on storage using LFN (FileReplicaAlreadyExists)"""
-        self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_lfn()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_lfn()
 
-    @raises(exception.FileReplicaAlreadyExists)
     def test_rename_mgr_FileReplicaAlreadyExists_single_pfn(self):
         """S3 (RSE/PROTOCOLS): Rename a single file on storage using PFN (FileReplicaAlreadyExists)"""
-        self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_pfn()
+        with pytest.raises(exception.FileReplicaAlreadyExists):
+            self.mtc.test_rename_mgr_FileReplicaAlreadyExists_single_pfn()
 
-    @raises(exception.SourceNotFound)
     def test_rename_mgr_SourceNotFound_multi(self):
         """S3 (RSE/PROTOCOLS): Rename multiple files on storage (SourceNotFound)"""
-        self.mtc.test_rename_mgr_SourceNotFound_multi()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_rename_mgr_SourceNotFound_multi()
 
-    @raises(exception.SourceNotFound)
     def test_rename_mgr_SourceNotFound_single_lfn(self):
         """S3 (RSE/PROTOCOLS): Rename a single file on storage using LFN (SourceNotFound)"""
-        self.mtc.test_rename_mgr_SourceNotFound_single_lfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_rename_mgr_SourceNotFound_single_lfn()
 
-    @raises(exception.SourceNotFound)
     def test_rename_mgr_SourceNotFound_single_pfn(self):
         """S3 (RSE/PROTOCOLS): Rename a single file on storage using PFN (SourceNotFound)"""
-        self.mtc.test_rename_mgr_SourceNotFound_single_pfn()
+        with pytest.raises(exception.SourceNotFound):
+            self.mtc.test_rename_mgr_SourceNotFound_single_pfn()
 
     def test_change_scope_mgr_ok_single_lfn(self):
         """S3 (RSE/PROTOCOLS): Change the scope of a single file on storage using LFN (Success)"""
